[PATCH 0/2] Multiparent diff tree-walker + combine-diff speedup
- From
Kirill Smelkov <kirr@mns.spb.ru>
- Date
- Feb 13, 2014, 14:02 UTC
- Message-ID
- <cover.1392299516.git.kirr@mns.spb.ru>
Here go combine-diff speedup patches in form of first reworking diff tree-walker to work in general case - when a commit have several parents, not only one - we are traversing all 1+nparent trees in parallel.
Then we are taking advantage of the new diff tree-walker for speeding up combine-diff, which for linux.git results in ~14 times speedup.
I understand v1.9.0 is going to be released first, but wanted to finally send the patches, so that people could start reviewing them.
Please apply on top of ks/tree-diff-more and thanks beforehand,
Kirill
Kirill Smelkov (2): tree-diff: rework diff_tree() to generate diffs for multiparent cases as well combine-diff: speed it up, by using multiparent diff tree-walker directly
combine-diff.c | 85 +++++++++- diff.c | 2 + diff.h | 10 ++ tree-diff.c | 501 +++++++++++++++++++++++++++++++++++++++++++++++++-------- 4 files changed, 529 insertions(+), 69 deletions(-)
-- 1.9.rc1.181.g641f458